/***************************************************
* Une radio Web qui se connecte aux reseau donl les*
*identifiants sont stockés sur une carte SD pour la*
*transportabilité d'un site à l'autre. la carte SD *
*contient 3 fichiers texte: SSID de la boxe, le Mot*
*de passe et l'URL de la station à écouter en      *
*streaming ... Cette carte multi usages est décrite*
*sur mon site http://amazing-vacuum-tubes.com      * 
***************************************************/

// Importation des besoins
#include "WiFi.h"
#include "Audio.h"
#include "SD.h"
#include "FS.h"
#include "LiquidCrystal_I2C.h"

// Connexion des I/Os
#define SD_CS          5
#define SPI_MOSI      23
#define SPI_MISO      19
#define SPI_SCK       18
#define I2S_DOUT      25
#define I2S_BCLK      27
#define I2S_LRC       26

Audio audio;

// Adresse du LCD,Nombre de carractères,Nombre de lignes
LiquidCrystal_I2C lcd(0x27,20,4);

String ssid ;
String password ;


void setup() {
    // initialise le lcd
    lcd.begin();                       
    lcd.backlight();

    // Topographie de la carte SD
    pinMode(SD_CS, OUTPUT);      
    digitalWrite(SD_CS, HIGH);
    SPI.begin(SPI_SCK, SPI_MISO, SPI_MOSI);
  
    // Initialiser la carte SD
    if (!SD.begin(SD_CS)) {
    lcd.println("Erreur lors de l'initialisation de la carte SD.");
    return;
    }

// Lecture de l'identifiant
File ssidFile = SD.open("/ssid.txt");

    // Vérifier si le fichier est ouvert
      if (ssidFile) {
    // Lire le contenu du fichier
        String data = ssidFile.readString();
        lcd.println(data);
        ssid = data;

    // Fermer le fichier
        ssidFile.close();
      } else {
        lcd.println("Erreur lors de l'ouverture du fichier ssid");
      }

// Lecture du Mot de passe
File passwordFile = SD.open("/password.txt");

    // Vérifier si le fichier est ouvert
      if (passwordFile) {
    // Lire le contenu du fichier
        String data = passwordFile.readString();
        password = data;

    // Fermer le fichier
        passwordFile.close();
      } else {
        lcd.println("Erreur lors de l'ouverture du fichier password");
      }
// connexion au Wi-Fi
    WiFi.disconnect();
    WiFi.mode(WIFI_STA);
    WiFi.begin(ssid.c_str(), password.c_str());
    while (WiFi.status() != WL_CONNECTED) delay(1500);
    audio.setPinout(I2S_BCLK, I2S_LRC, I2S_DOUT);
    audio.setVolume(19); // Volume de sortie 21 = ~0 dB sur 600 ohms

// Lecture de l'adresse station radio
    File dataFile = SD.open("/radio.txt");

    // Vérifier si le fichier est ouvert
      if (dataFile) {
    // Lire le contenu du fichier
        String data = dataFile.readString();
        const char *station = data.c_str();
        audio.connecttohost(station);
    // Fermer le fichier
        dataFile.close();
      } else {
        lcd.println("Erreur lors de l'ouverture du fichier Station Radio");
      }
}

void loop()
{
    audio.loop();
}

// Affichage station et titre si dispo dans le streaming sur le LCD

void audio_showstation(const char *info){
    lcd.setCursor(0, 0);
    lcd.print(info);
    delay (2000);
    
}
void audio_showstreamtitle(const char *info){
    lcd.clear();
    lcd.home();
    lcd.print(info);        
}
